#!/usr/bin/python

import sys


package_name = "telepathy-gabble"
package_dir = "/usr/share/%s-tests" % package_name

normal_tests_env = \
    "G_DEBUG=fatal-warnings,fatal-criticals " \
    "sh %s/with-session-bus.sh " \
    "--config-file=%s/dbus-1/session.conf --" % \
    (package_dir, package_dir)
normal_tests = [
    "test-base64",
    "test-caps-hash",
    "test-dtube-unique-names",
    "test-gabble-idle-weak",
    "test-handles",
    "test-jid-decode",
    "test-parse-message",
    "test-presence",
    "test-tp-error-from-wocky"
    ]

twisted_tests_env = \
    "PYTHONPATH=%s/twisted " \
    "sh %s/with-session-bus.sh "\
    "--config-file=%s/dbus-1/session.conf -- " \
    "/usr/bin/python2.5" % \
    (package_dir, package_dir, package_dir)
twisted_tests = [
    "twisted/caps_helper.py",
    "twisted/servicetest.py",
    "twisted/avatar-requirements.py",
    "twisted/caps/advertise-contact-caps.py",
    "twisted/caps/advertise-legacy.py",
    "twisted/caps/caps-cache.py",
    "twisted/caps/caps-persistent-cache.py",
    "twisted/caps/compat-bundles.py",
    "twisted/caps/double-disco.py",
    "twisted/caps/disco-without-node.py",
    "twisted/caps/from-bare-jid.py",
    "twisted/caps/hashed-caps.py",
    "twisted/caps/initial-caps.py",
    "twisted/caps/jingle-caps.py",
    "twisted/caps/receive-jingle.py",
    "twisted/caps/trust-thyself.py",
    "twisted/caps/tube-caps.py",
    # Randomly fails; see https://bugs.freedesktop.org/show_bug.cgi?id=37381
    #"twisted/client-types.py",
    # The plugin needed for this test is disabled.
    #"twisted/cm/protocol.py",
    "twisted/gateways.py",
    "twisted/muc/conference.py",
    "twisted/muc/chat-states.py",
    "twisted/muc/name-conflict.py",
    "twisted/muc/presence-before-closing.py",
    "twisted/muc/renamed.py",
    "twisted/muc/roomlist.py",
    "twisted/muc/scrollback.py",
    "twisted/muc/send-error.py",
    "twisted/muc/subject.py",
    "twisted/muc/test-ensure.py",
    "twisted/muc/test-muc-alias.py",
    "twisted/muc/test-muc-invitation.py",
    "twisted/muc/test-muc-ownership.py",
    "twisted/muc/test-muc-properties.py",
    "twisted/muc/test-muc.py",
    "twisted/olpc/current-activity.py",
    "twisted/olpc/olpc-muc-invitation.py",
    "twisted/olpc/olpc-muc-prop-change.py",
    "twisted/olpc/test-olpc-bundle.py",
    "twisted/olpc/test-olpc-set-props-preload.py",
    "twisted/olpc/change-notifications.py",
    "twisted/pep-support.py",
    "twisted/power-save.py",
    "twisted/presence/decloak.py",
    "twisted/presence/initial-contact-presence.py",
    "twisted/presence/initial-presence.py",
    "twisted/presence/invisible_xep_0126.py",
    "twisted/presence/invisible_xep_0186.py",
    "twisted/presence/presence.py",
    # The plugin needed for this test is disabled.
    #"twisted/presence/plugins.py",
    "twisted/presence/set-idempotence.py",
    "twisted/presence/shared-status.py",
    "twisted/roster/authorize.py",
    "twisted/roster/edit-before-roster.py",
    "twisted/roster/ensure.py",
    "twisted/roster/groups.py",
    "twisted/roster/groups-12791.py",
    "twisted/roster/removed-from-rp-subscribe.py",
    "twisted/roster/request-group-before-roster.py",
    "twisted/roster/request-group-after-roster.py",
    "twisted/roster/test-google-roster.py",
    "twisted/roster/test-roster.py",
    "twisted/roster/test-roster-item-deletion.py",
    "twisted/roster/test-roster-subscribe.py",
    "twisted/roster/test-save-alias-to-roster.py",
    "twisted/sasl/abort.py",
    "twisted/sasl/close.py",
    "twisted/sasl/jabber_auth.py",
    "twisted/sasl/plain.py",
    "twisted/sasl/complex.py",
    "twisted/sasl/telepathy-password.py",
    "twisted/search/ceci-nest-pas-un-serveur.py",
    "twisted/search/extended.py",
    "twisted/search/no-server-property.py",
    "twisted/search/unextended.py",
    "twisted/text/initiate.py",
    "twisted/text/initiate-requestotron.py",
    "twisted/text/destroy.py",
    "twisted/text/ensure.py",
    "twisted/text/respawn.py",
    "twisted/text/send-error.py",
    "twisted/text/send-to-correct-resource.py",
    "twisted/text/test-chat-state.py",
    "twisted/text/test-text-delayed.py",
    "twisted/text/test-text-no-body.py",
    "twisted/text/test-text.py",
    # FIXME: This test fails only if run through the CITA tests...
    #"twisted/tls/server-tls-channel.py",
    "twisted/tubes/accept-muc-dbus-tube.py",
    "twisted/tubes/accept-muc-stream-tube.py",
    "twisted/tubes/accept-private-dbus-tube.py",
    "twisted/tubes/accept-private-stream-tube.py",
    "twisted/tubes/check-create-tube-return.py",
    "twisted/tubes/close-muc-with-closed-tube.py",
    "twisted/tubes/crash-on-list-channels.py",
    "twisted/tubes/create-invalid-tube-channels.py",
    "twisted/tubes/ensure-si-tube.py",
    "twisted/tubes/muc-presence.py",
    "twisted/tubes/offer-muc-dbus-tube.py",
    "twisted/tubes/offer-muc-stream-tube.py",
    "twisted/tubes/offer-no-caps.py",
    "twisted/tubes/offer-private-dbus-tube.py",
    "twisted/tubes/offer-private-stream-tube.py",
    "twisted/tubes/request-invalid-dbus-tube.py",
    "twisted/tubes/test-get-available-tubes.py",
    # SOCKS5 doesn't work correctly in Harmattan.
    #"twisted/tubes/test-socks5-muc.py",
    "twisted/vcard/disconnect-during-pep.py",
    "twisted/vcard/get-contact-info.py",
    "twisted/vcard/item-not-found.py",
    "twisted/vcard/overlapping-sets.py",
    "twisted/vcard/redundant-set.py",
    "twisted/vcard/refresh-contact-info.py",
    "twisted/vcard/set-contact-info.py",
    "twisted/vcard/set-set-disconnect.py",
    "twisted/vcard/supported-fields.py",
    "twisted/vcard/test-alias-empty-vcard.py",
    "twisted/vcard/test-alias-pep.py",
    "twisted/vcard/test-alias.py",
    "twisted/vcard/test-avatar-async.py",
    "twisted/vcard/test-avatar.py",
    "twisted/vcard/test-avatar-retrieved.py",
    "twisted/vcard/test-avatar-tokens.py",
    "twisted/vcard/test-avatar-multiple-resources.py",
    "twisted/vcard/test-save-alias-to-vcard.py",
    "twisted/vcard/test-set-alias.py",
    "twisted/vcard/test-vcard-cache.py",
    "twisted/vcard/test-vcard-race.py",
    "twisted/vcard/update-get-failed.py",
    "twisted/vcard/update-rejected.py",
    "twisted/jingle/accept-extra-stream.py",
    # We build gabble with --disable-channel-type-call.
    #"twisted/jingle/call-basics.py",
    #"twisted/jingle/call-codecoffer.py",
    #"twisted/jingle/call-dtmf.py",
    "twisted/jingle/call-muc.py",
    "twisted/jingle/call-muc-cancel.py",
    "twisted/jingle/call-muc-re-re-request.py",
    "twisted/jingle/call-state.py",
    "twisted/jingle/decloak-peer.py",
    "twisted/jingle/dtmf.py",
    "twisted/jingle/dtmf-no-audio.py",
    "twisted/jingle/google-relay.py",
    "twisted/jingle/hold-audio.py",
    "twisted/jingle/hold-av.py",
    "twisted/jingle/incoming-basics.py",
    "twisted/jingle/incoming-call-stream-error.py",
    "twisted/jingle/initial-audio-video.py",
    "twisted/jingle/misuse.py",
    "twisted/jingle/stun-server.py",
    "twisted/jingle/transport-info-parsing.py",
    # This takes about two years and a half to run and CITA doesn't like it.
    #"twisted/jingle/outgoing-basics.py",
    "twisted/jingle/outgoing-ensure.py",
    "twisted/jingle/outgoing-many-streams.py",
    "twisted/jingle/payload-types.py",
    "twisted/jingle/preload-caps-crash.py",
    "twisted/jingle/session-id-collision.py",
    "twisted/jingle/stream-errors-on-terminate.py",
    "twisted/jingle/stream-errors-on-content-reject.py",
    "twisted/jingle/stream-handler-error.py",
    "twisted/jingle/test-content-adding-removal.py",
    "twisted/jingle/test-description-info.py",
    "twisted/jingle/test-incoming-call-reject.py",
    "twisted/jingle/test-incoming-iceudp.py",
    "twisted/jingle/test-outgoing-call-rejected.py",
    "twisted/jingle/test-outgoing-iceudp.py",
    "twisted/jingle/test-content-complex.py",
    # Doesn't work and leaks the connection.
    #"twisted/jingle/test-wait-for-caps.py",
    #"twisted/jingle/test-wait-for-caps-incomplete.py",
    # SOCKS5 doesn't work correctly in Harmattan.
    #"twisted/jingle-share/test-caps-file-transfer.py",
    #"twisted/jingle-share/test-send-file.py",
    #"twisted/jingle-share/test-send-file-send-before-accept.py",
    #"twisted/jingle-share/test-receive-file-and-close-socket-while-receiving.py",
    #"twisted/jingle-share/test-receive-file-and-disconnect.py",
    #"twisted/jingle-share/test-receive-file-and-sender-disconnect-while-pending.py",
    #"twisted/jingle-share/test-receive-file-and-sender-disconnect-while-transfering.py",
    #"twisted/jingle-share/test-receive-file-decline.py",
    #"twisted/jingle-share/test-send-file-and-cancel-immediately.py",
    #"twisted/jingle-share/test-send-file-wait-to-provide.py",
    #"twisted/jingle-share/test-multift.py",
    # Disable the file transfer tests; they don't work correctly in
    # Harmattan
    #"twisted/file-transfer/test-caps-file-transfer.py",
    #"twisted/file-transfer/test-ibb-too-early.py",
    #"twisted/file-transfer/test-receive-file-and-close-socket-while-receiving.py",
    #"twisted/file-transfer/test-receive-file-and-disconnect.py",
    #"twisted/file-transfer/test-receive-file-and-sender-disconnect-while-pending.py",
    #"twisted/file-transfer/test-receive-file-and-sender-disconnect-while-transfering.py",
    #"twisted/file-transfer/test-receive-file-decline.py",
    #"twisted/file-transfer/test-receive-file.py",
    #"twisted/file-transfer/test-send-file-and-cancel-immediately.py",
    #"twisted/file-transfer/test-send-file-declined.py",
    #"twisted/file-transfer/test-send-file-provide-immediately.py",
    #"twisted/file-transfer/test-send-file-to-unknown-contact.py",
    #"twisted/file-transfer/test-send-file-wait-to-provide.py",
    #"twisted/file-transfer/test-send-file-send-before-accept.py",
    # Disable the debug test.
    #"twisted/test-debug.py",
    "twisted/connect/disco-error-from-bare-jid.py",
    "twisted/connect/disco-no-reply.py",
    "twisted/connect/disconnect-timeout.py",
    "twisted/connect/test-fail.py",
    "twisted/connect/test-success.py",
    "twisted/connect/test-twice.py",
    "twisted/connect/test-nonblocking-tls.py",
    "twisted/connect/stream-closed.py",
    "twisted/connect/network-error.py",
    # Takes too long to run.
    #"twisted/connect/torture.py",
    # SOCKS5 doesn't work correctly in Harmattan.
    #"twisted/test-fallback-socks5-proxy.py",
    "twisted/test-register.py",
    "twisted/test-location.py",
    "twisted/pubsub.py",
    # The plugin needed for sidecar tests is disabled.
    #"twisted/sidecar-own-caps.py",
    #"twisted/sidecars.py",
    "twisted/mail-notification.py"
    ]

tests_description = [
    ["normal-unit-tests", "Normal Unit tests",
     normal_tests_env, normal_tests],
    ["twisted-unit-tests", "Twisted unit tests",
     twisted_tests_env, twisted_tests]]


def main(args):
    print 'Creating tests.xml file.'

    # open file for output
    output_file = open('tests.xml', 'w')

    # add header information
    output_file.write('<?xml version="1.0" encoding="ISO-8859-1"?>\n')
    output_file.write('<testdefinition version="0.1">\n')
    output_file.write('  <suite name="%s-tests">\n' % package_name)
    output_file.write('\n')

    input_line = 'begin'
    last_input_line = None

    for description in tests_description:
        set_name = description[0]
        set_description = description[1]
        cases_env = description[2]
        cases = description[3]

        output_file.write('    <set name="%s" description="%s" feature="%s">\n' % \
                          (set_name, set_description, package_name))
        output_file.write('\n')

        for case in cases:
            output_file.write('      <case name="%s" level="Component" type="Functional" description="%s">\n' % \
                              (case, case))
            output_file.write('        <step expected_result="0">%s %s/%s</step>\n' % \
                              (cases_env, package_dir, case))
            output_file.write('      </case>\n')

        output_file.write('\n')
        output_file.write('      <environments>\n')
        output_file.write('        <hardware>true</hardware>\n')
        output_file.write('      </environments>\n')
        output_file.write('\n')
        output_file.write('    </set>\n')
        output_file.write('\n')

    output_file.write('  </suite>\n')
    output_file.write('</testdefinition>')
    output_file.close()


if __name__ == '__main__':
    main(sys.argv[1:])
    sys.exit(0)
