# Included by debian/rules.

# Use Maemo's Python, not the ancient Python provided by Scratchbox
DEB_CONFIGURE_EXTRA_FLAGS += PYTHON=/usr/bin/python2.6
# Use OpenSSL rather than GnuTLS (since the latter is not available on Maemo)
DEB_CONFIGURE_EXTRA_FLAGS += --with-wocky-tls=openssl
# specify the location of our CA certificate directory
DEB_CONFIGURE_EXTRA_FLAGS += --with-ca-certificates=/etc/ssl/certs
# We want to support plugins on Maemo
DEB_CONFIGURE_EXTRA_FLAGS += --enable-plugin-api
# We're a phone on Maemo
DEB_CONFIGURE_EXTRA_FLAGS += --enable-is-a-phone
# Disable Channel.Type.Call for now
DEB_CONFIGURE_EXTRA_FLAGS += --disable-channel-type-call

# Use soft-float and thumb mode if it enabled.
ifneq (,$(findstring thumb,$(DEB_BUILD_OPTIONS)))
	CFLAGS += -mthumb
endif

ifneq (,$(findstring coverage,$(DEB_BUILD_OPTIONS)))
	SBOX_USE_CCACHE := no
	DEB_CONFIGURE_EXTRA_FLAGS += --enable-coverage
endif

ifeq (,$(findstring debug,$(DEB_BUILD_OPTIONS)))
    CFLAGS += -DG_DISABLE_CAST_CHECKS
    # Don't assert when critical warnings happen
    DEB_CONFIGURE_EXTRA_FLAGS += --disable-fatal-criticals
endif

# Use parallel jobs if possible
ifneq (,$(findstring parallel,$(DEB_BUILD_OPTIONS)))
	PARALLEL_JOBS := $(shell echo $(DEB_BUILD_OPTIONS) | \
		sed -e 's/.*parallel=\([0-9]\+\).*/\1/')
	ifeq ($(DEB_BUILD_OPTIONS),$(PARALLEL_JOBS))
		PARALLEL_JOBS := $(shell if [ -f /proc/cpuinfo ]; \
			then echo `cat /proc/cpuinfo | grep 'processor' | wc -l`; \
			else echo 1; fi)
	endif
	NJOBS := -j$(PARALLEL_JOBS)
endif
DEB_MAKE_ENVVARS := MAKEFLAGS=$(NJOBS)

pre-build:: patch configure

configure:
	ACLOCAL=aclocal-1.9 \
		sh ./autogen.sh --no-configure

clean::
	rm -f configure
#
# this has a tight dependency, so we can symlink the doc directories together
DEB_INSTALL_DOCS_telepathy-gabble-dev := --no-act
DEB_INSTALL_CHANGELOGS_telepathy-gabble-dev := --no-act

# Stolen from:
#   http://maemo.gitorious.org/maemo-multimedia/gstreamer/blobs/355bac5f181033352350dbc4611f3ab751a4615e/debian/rules#line268
# Thanks folks! Here's how you release a new version to Maemo:
#
#   # merge the tag into harmattan
# % git checkout harmattan
# % git merge telepathy-gabble-0.12.x
#
#   # there will be conflicts in lib/ext/wocky and lib/ext/telepathy-yell; just do
# % git reset lib/ext/wocky
# % git reset lib/ext/telepathy-yell
# % git commit -a
#
#   # Now update the wocky and telepathy-yell snapshots:
# % ./debian/rules update-submodules UPSTREAM_REF=telepathy-gabble-0.12.x
#    [ lots of crap flies past ]
# lib/ext/wocky update to [git rev. id] staged, git commit to proceed
# lib/ext/telepathy-yell update to [git rev. id] staged, git commit to proceed
#
#   # Make sure the rev. id is what you think it should be! If you've deviated
#   # from the above (maybe by cherry-picking a commit) then you'll lose,
#   # because the submodule rev. id is taken from the *merge base* of
#   # 'harmattan' and $UPSTREAM_REF. wjt has lost many a frustrating hour to
#   # this.
#
# % git commit -m 'Update wocky and yell snapshots'
#
#   # and now you can dch -v, etc. as normal.

UPSTREAM_REF=master

update-wocky: COMMIT := $(shell git rev-parse $(shell git rev-parse --verify MERGE_HEAD || git merge-base $(UPSTREAM_REF) HEAD):lib/ext/wocky)
update-wocky:
	@if ! git diff-files --ignore-submodules --quiet lib/ext/wocky || \
		! git diff-index --ignore-submodules --cached --quiet HEAD -- lib/ext/wocky; then \
			echo "your lib/ext/wocky/ directory state is dirty"; \
			exit 1; \
		fi
	if test -d $(CURDIR)/lib/ext/wocky ; then rm -rfv $(CURDIR)/lib/ext/wocky ; git rm -r --cached --ignore-unmatch $(CURDIR)/lib/ext/wocky ; fi
	git clone -n git://anongit.freedesktop.org/wocky $(CURDIR)/lib/ext/wocky
	cd $(CURDIR)/lib/ext/wocky && git checkout -f $(COMMIT)
	rm -rfv $(CURDIR)/lib/ext/wocky/.git
	git add $(CURDIR)/lib/ext/wocky
	@echo "lib/ext/wocky update to $(COMMIT) staged, git commit to proceed"

update-yell: COMMIT := $(shell git rev-parse $(shell git rev-parse --verify MERGE_HEAD || git merge-base $(UPSTREAM_REF) HEAD):lib/ext/telepathy-yell)
update-yell:
	@if ! git diff-files --ignore-submodules --quiet lib/ext/telepathy-yell || \
		! git diff-index --ignore-submodules --cached --quiet HEAD -- lib/ext/telepathy-yell; then \
			echo "your lib/ext/telepathy-yell/ directory state is dirty"; \
			exit 1; \
		fi
	if test -d $(CURDIR)/lib/ext/telepathy-yell ; then rm -rfv $(CURDIR)/lib/ext/telepathy-yell ; git rm -r --cached --ignore-unmatch $(CURDIR)/lib/ext/telepathy-yell ; fi
	git clone -n git://anongit.freedesktop.org/telepathy/telepathy-yell.git $(CURDIR)/lib/ext/telepathy-yell
	cd $(CURDIR)/lib/ext/telepathy-yell && git checkout -f $(COMMIT)
	rm -rfv $(CURDIR)/lib/ext/telepathy-yell/.git
	git add $(CURDIR)/lib/ext/telepathy-yell
	@echo "lib/ext/telepathy-yell update to $(COMMIT) staged, git commit to proceed"

update-submodules: update-wocky update-yell
